pub const fn trade_module_address_for(
environment: DeriveEnvironment,
) -> &'static strExpand description
Returns the Trade module contract address constant for the configured environment.
pub const fn trade_module_address_for(
environment: DeriveEnvironment,
) -> &'static strReturns the Trade module contract address constant for the configured environment.